Package: annotate
Title: Annotation for microarrays
Version: 1.90.0
Author: R. Gentleman
Authors@R: c(
        person("Jeff", "Gentry", role = "aut"),
        person("Kritika", "Verma", role = "ctb",
                comment = "Converted chromLOC vignette from Sweave to RMarkdown / HTML."),
        person("Manvi", "Yaduvanshi", role = "ctb",
                comment = "Converted useDataPkgs vignette from Sweave to RMarkdown / HTML."),
        person("Bioconductor Package Maintainer",
                email = "maintainer@bioconductor.org", role = "cre"))
Description: Using R enviroments for annotation.
Depends: R (>= 2.10), AnnotationDbi (>= 1.27.5), XML
Imports: Biobase, DBI, xtable, graphics, utils, stats, methods,
        BiocGenerics (>= 0.13.8), httr
Suggests: hgu95av2.db, genefilter, Biostrings (>= 2.25.10), IRanges,
        rae230a.db, rae230aprobe, tkWidgets, GO.db, org.Hs.eg.db,
        org.Mm.eg.db, humanCHRLOC, Rgraphviz, RUnit, BiocStyle, knitr
VignetteBuilder: knitr
License: Artistic-2.0
LazyLoad: yes
Collate: AllGenerics.R ACCNUMStats.R Amat.R AnnMaps.R chromLocation.R
        compatipleVersions.R findNeighbors.R getData.R getPMInfo.R
        getSeq4ACC.R GOhelpers.R homoData.R html.R isValidKey.R
        LL2homology.R pmid2MIAME.R pubMedAbst.R query.R readGEOAnn.R
        serializeEnv.R blastSequences.R zzz.R test_annotate_package.R
biocViews: Annotation, Pathways, GO
Packaged: 2026-04-28 20:36:08 UTC; biocbuild
git_url: https://git.bioconductor.org/packages/annotate
git_branch: RELEASE_3_23
git_last_commit: d5d1236
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Maintainer: Bioconductor Package Maintainer <maintainer@bioconductor.org>
