import(methods)

import(BiocGenerics)

importClassesFrom(Biobase,
                  eSet)

importClassesFrom(AnnotationDbi,
                  FlatBimap)

importMethodsFrom(DBI, dbGetQuery, dbListTables, dbListFields)

importMethodsFrom(AnnotationDbi,
                  Definition,
                  GOID,
                  Secondary,
                  Synonym,
                  colnames,
                  columns,
                  dbmeta,
                  eapply,
                  exists,
                  get,
                  ls,
                  mappedRkeys,
                  mget,
                  ncol,
                  nrow,
                  Ontology,
                  revmap,
                  Term)

importMethodsFrom(Biobase,
                  annotation,
                  contents,
                  exprs,
                  featureNames)

importFrom(Biobase,
           addVigs2WinMenu)

importFrom(graphics,
           abline,
           identify,
           plot)

importFrom(stats,
           setNames,
           heatmap)

importFrom(utils,
           browseURL,
           compareVersion,
           packageDescription,
           URLencode)

importFrom(xtable,
           xtable)

importFrom(httr,
           GET)

importFrom(XML,
           getNodeSet,
           htmlParse,
           xmlChildren,
           xmlDOMApply,
           xmlErrorCumulator,
           xmlName,
           xmlParse,
           xmlRoot,
           xmlToDataFrame,
           xmlTreeParse,
           xmlValue,
           xpathApply,
           xpathSApply)

exportClasses(
              chromLocation,
              FramedHTMLPage,
              homoData,
              HTMLPage,
              pubMedAbst
              )

exportMethods(
              abstText,
              articleTitle,
              authors,
              chromInfo,
              chromLengths,
              chromLocs,
              chromNames,
              dataSource,
              Definition,
              fileName,
              geneSymbols,
              GOID,
              homoACC,
              homoHGID,
              homoLL,
              homoOrg,
              homoPS,
              homoType,
              homoURL,
              initialize,
              journal,
              mainPage,
              nChrom,
              Ontology,
              organism,
              pageText,
              pageTitle,
              pmid,
              probesToChrom,
              pubDate,
              pubMedAbst,
              Secondary,
              show,
              sidePage,
              Synonym,
              Term,
              toFile,
              topPage
              )

export(
       .buildAnnotateOpts,
       .getIdTag,
       .getNcbiURL,
       .handleXML,
       .efetch,
       .transformAccession,
       ACC2homology,
       accessionToUID,
       ACCNUMStats,
       annPkgName,
       aqListGOIDs,
       buildChromLocation,
       buildPubMedAbst,
       checkArgs,
       chrCats,
       compatibleVersions,
       createLLChrCats,
       createMAPIncMat,
       dropECode,
       filterGOByOntology,
       findChr4LL,
       findNeighbors,
       genbank,
       getAnnMap,
       getBoundary,
       getEG,
       getEvidence,
       getGI,
       getGO,
       getGOChildren,
       getGOdesc,
       getGOOntology,
       getGOParents,
       getGOTerm,
       getGPLNames,
       getOntology,
       getOrgNameNCode,
       getPMID,
       getPMInfo,
       getQueryLink,
       getSAGEFileInfo,
       getSAGEGPL,
       getSEQ,
       getSYMBOL,
       getUniqAnnItem,
       getValidChr,
       GO2heatmap,
       GOmnplot,
       hasGOannote,
       HGID2homology,
       homoData,
       htmlpage,
       KEGG2heatmap,
       KEGGmnplot,
       LL2homology,
       lookUp,
       makeAnchor,
       mapOrgs,
       pm.abstGrep,
       pm.getabst,
       pm.titles,
       pmAbst2HTML,
       pmid2MIAME,
       PMIDAmat,
       pmidQuery,
       pubmed,
       PWAmat,
       readGEOAnn,
       readIDNAcc,
       readUrl,
       serializeDataPkgEnvs,
       serializeEnv,
       UniGeneQuery,
       entrezGeneByID,
       entrezGeneQuery,
       usedChromGenes,
       usedChromGenes,
       weightByConfi,
       whatACC,
       setRepository,
       getRepositories,
       clearRepository,
       isValidKey,
       allValidKeys,
       updateSymbolsToValidKeys,
       blastSequences
       )
